#!/usr/bin/env python3
#
# SPDX-FileCopyrightText: 2021 Volker Krause <vkrause@kde.org>
# SPDX-License-Identifier: LGPL-2.0-or-later
#
# Converts a serialized journey query response into GeoJSON
# Useful for inspecting navigation path details in QGIS
#

import argparse
import json
import os
import re

parser = argparse.ArgumentParser(description='Generates a GeoJSON document from journey query result')
parser.add_argument('--journey', type=str, required=True, help='Path to the journey JSON')
arguments = parser.parse_args()

output = {}
output['type'] = 'FeatureCollection'
output['name'] = 'Journey Paths'
output['features'] = []

inFile = open(arguments.journey, 'r')
inJson = json.load(inFile)

for journey in inJson:
    for section in journey['sections']:
        if not 'path' in section:
            continue
        for path in section['path']['sections']:
            properties = {}
            properties['name'] = path.get('description', '<anonymous>')
            feature = {}
            feature['type'] = 'Feature'
            feature['properties'] = properties
            feature['geometry'] = path.get('path', {})
            output['features'].append(feature)

print(json.dumps(output))



#!/usr/bin/env python3

# SPDX-FileCopyrightText: 2024 Jonah Brüchert <jbb@kaidan.im>
#
# SPDX-License-Identifier: LGPL-2.0-or-later

import sys
from bs4 import BeautifulSoup
import subprocess

table_path = sys.argv[1]
cpp_path   = sys.argv[2]

table = open(table_path, "r")
soup = BeautifulSoup(table, 'html.parser')

rows = soup.find_all("tr")

map = {}

for row in rows:
	data = row.find_all("td")
	if len(data) == 8:
		map[data[0].get_text().strip()] = data[2].get_text().strip()
		map[data[1].get_text().strip()] = data[3].get_text().strip()

	if len(data) == 4:
	        map[data[0].get_text().strip()] = data[1].get_text().strip()


out = open(cpp_path, "w")
out.write("{\n")
for row in map.items():
	k = row[0]
	v = row[1]
	out.write(f"    {{u'{k}', u\"{v}\"}},\n")

out.write("}")
out.close()



#!/usr/bin/env python3
#
# SPDX-FileCopyrightText: 2021 Volker Krause <vkrause@kde.org>
# SPDX-License-Identifier: LGPL-2.0-or-later
#
# Generates a GeoJSON document from coverage areas of the Transport API Repository
#

import argparse
import glob
import json
import os
import re

parser = argparse.ArgumentParser(description='Generates a GeoJSON document from coverage areas of the Transport API Repository')
parser.add_argument('--transport-api', type=str, required=True, help='Path to the Transport API Repository checkout')
arguments = parser.parse_args()

output = {}
output['type'] = 'FeatureCollection'
output['name'] = 'Transport API Repository Coverage Data'
output['features'] = []

transportApiFiles = glob.glob(arguments.transport_api + "/*.json", recursive=True)
for transportApiFile in transportApiFiles:
    f = open(transportApiFile, 'r')
    j = json.load(f)
    nameMatch = re.search('/([a-z]{2})/(.*)\\.json', transportApiFile)
    if nameMatch:
        name = nameMatch.group(1) + '-' + nameMatch.group(2)
    else:
        name = os.path.splitext(os.path.basename(transportApiFile))[0]

    for cov in ['anyCoverage', 'regularCoverage', 'realtimeCoverage']:
        if not 'coverage' in j or not cov in j['coverage']:
            continue
        area = {}
        if 'area' in j['coverage'][cov]:
            area = j['coverage'][cov]['area']
        elif 'areaFile' in j['coverage'][cov]:
            areaFile = open(arguments.transport_api + "/geometry/" + j['coverage'][cov]['areaFile'], 'r')
            area = json.load(areaFile)
        else:
            continue
        properties = {}
        properties['name'] = name + '-' + cov
        feature = {}
        feature['type'] = 'Feature'
        feature['properties'] = properties
        feature['geometry'] = area
        output['features'].append(feature)

print(json.dumps(output))



#!/usr/bin/env python3

# SPDX-FileCopyrightText: 2024 Jonah Brüchert <jbb@kaidan.im>
# SPDX-License-Identifier: LGPL-2.0-or-later

import json

import sys

if len(sys.argv) < 3:
    print("Usage: ./process_geojson.py input.geojson country_network.json")
    sys.exit(1)

geojson_path = sys.argv[1]
output_path = sys.argv[2]

geojson = json.load(open(geojson_path, "r"))
if geojson["type"] != "FeatureCollection":
    print("Error: Unsupported GeoJSON type, this script only understands FeatureCollection")
    sys.exit(1)

timestamp = geojson["timestamp"]
features = geojson["features"]

stations = []

for feature in features:
    if feature["type"] != "Feature":
        print("Error: Unsupported feature type, this script only understands Feature")
        sys.exit(1)

    if feature["geometry"]["type"] != "Point":
        print("Error: Unsupported geometry, this script only understands Point. Make sure not to use geo in your Overpass Turbo query")
        sys.exit(1)

    properties = feature["properties"]
    name_keys = filter(lambda k: k.startswith("name") or k.startswith("alt_name") or k.startswith("int_name"), properties.keys())
    station = {k: properties[k] for k in name_keys}
    station["longitude"] = feature["geometry"]["coordinates"][1]
    station["latitude"] = feature["geometry"]["coordinates"][0]
    stations.append(station)

station_file = open(output_path, "w")
json.dump(stations, station_file, ensure_ascii=False)



#!/usr/bin/env python3
#
# SPDX-FileCopyrightText: 2021 Volker Krause <vkrause@kde.org>
# SPDX-License-Identifier: LGPL-2.0-or-later
#
# Converts our GBFS feed repository into GeoJSON
# Useful for inspecting GBFS coverage areas

import argparse
import json
import os
import re

parser = argparse.ArgumentParser(description='Generates a GeoJSON document from GBFS feed repository')
parser.add_argument('--feeds', type=str, required=True, help='Path to the GBFS feed repository file')
arguments = parser.parse_args()

output = {}
output['type'] = 'FeatureCollection'
output['name'] = 'GBFS Feeds'
output['features'] = []

inFile = open(arguments.feeds, 'r')
inJson = json.load(inFile)

for feed in inJson:
    properties = {}
    properties['name'] = feed['systemId']
    properties['url'] = feed['discoveryUrl']
    feature = {}
    feature['type'] = 'Feature'
    feature['properties'] = properties

    geometry = {}
    geometry['type'] = 'Polygon'
    bb = feed['boudingBox']
    coords = [[bb['x1'], bb['y1']], [bb['x2'], bb['y1']], [bb['x2'], bb['y2']], [bb['x1'], bb['y2']], [bb['x1'], bb['y1']]]
    geometry['coordinates'] = [coords]
    feature['geometry'] = geometry

    output['features'].append(feature)

print(json.dumps(output))

